/* 
 * Just some rules to fill in
 */

.flop-slider {
    position: relative;
    display: block;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    -ms-touch-action: pan-y;
    touch-action: pan-y;
    -webkit-tap-highlight-color: transparent;
}
.flop-list {
    position: relative;
    overflow: hidden;
    display: block;
    margin: 0;
    padding: 0;

    &:focus {
        outline: none;
    }

    &.dragging {
        cursor: pointer;
        cursor: hand;
    }
}
.flop-slider .flop-track,
.flop-slider .flop-list {
    -webkit-transform: translate3d(0, 0, 0);
    -moz-transform: translate3d(0, 0, 0);
    -ms-transform: translate3d(0, 0, 0);
    -o-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
}

.flop-track {
    position: relative;
    left: 0;
    top: 0;
    display: block;

    &:before,
    &:after {
        content: "";
        display: table;
    }

    &:after {
        clear: both;
    }

    .flop-loading & {
        visibility: hidden;
    }
}
.flop-slide {
    float: left;
    height: 100%;
    min-height: 1px;
    [dir="rtl"] & {
        float: right;
    }
    img {
        display: block;
    }
    &.flop-loading img {
        display: none;
    }

    display: none;

    &.dragging img {
        pointer-events: none;
    }

    .flop-initialized & {
        display: block;
    }

    .flop-loading & {
        visibility: hidden;
    }

    .flop-vertical & {
        display: block;
        height: auto;
        border: 1px solid transparent;
    }
}

/*
 * Cookie Law banner
 */
#cookie-law-container{
    padding: 10px 0;
    
    .explain p{
        font-size: 12px;
        margin-bottom: 5px !important;
        
        &:last-child{
            margin-bottom: 0 !important;
        }

    }
}