/*
 * Basic main scss file
 */
/*
 * Just some rules to fill in
 */
@import url("http://foo.bar/dummy");
/* line 5, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slider {
  position: relative;
  display: block;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  -ms-touch-action: pan-y;
  touch-action: pan-y;
  -webkit-tap-highlight-color: transparent;
}

/* line 20, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-list {
  position: relative;
  overflow: hidden;
  display: block;
  margin: 0;
  padding: 0;
}

/* line 27, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-list:focus {
  outline: none;
}

/* line 31, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-list.dragging {
  cursor: pointer;
  cursor: hand;
}

/* line 36, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slider .flop-track,
.flop-slider .flop-list {
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  -ms-transform: translate3d(0, 0, 0);
  -o-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
}

/* line 45, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-track {
  position: relative;
  left: 0;
  top: 0;
  display: block;
}

/* line 51, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-track:before, .flop-track:after {
  content: "";
  display: table;
}

/* line 57, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-track:after {
  clear: both;
}

/* line 61, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-loading .flop-track {
  visibility: hidden;
}

/* line 65, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slide {
  float: left;
  height: 100%;
  min-height: 1px;
  display: none;
}

/* line 69, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
[dir="rtl"] .flop-slide {
  float: right;
}

/* line 72, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slide img {
  display: block;
}

/* line 75, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slide.flop-loading img {
  display: none;
}

/* line 81, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-slide.dragging img {
  pointer-events: none;
}

/* line 85, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-initialized .flop-slide {
  display: block;
}

/* line 89, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-loading .flop-slide {
  visibility: hidden;
}

/* line 93, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
.flop-vertical .flop-slide {
  display: block;
  height: auto;
  border: 1px solid transparent;
}

/*
 * Cookie Law banner
 */
/* line 103, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
#cookie-law-container {
  padding: 10px 0;
}

/* line 106, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
#cookie-law-container .explain p {
  font-size: 12px;
  margin-bottom: 5px !important;
}

/* line 110, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/_vendor.scss */
#cookie-law-container .explain p:last-child {
  margin-bottom: 0 !important;
}

/*
 * Webfont for icons
 */
@font-face {
  font-family: 'icomoon';
  src: font-url("icomoon.eot");
  src: font-url("icomoon.eot?#iefix") format("embedded-opentype"), font-url("icomoon.ttf") format("truetype"), font-url("icomoon.woff") format("woff"), font-url("icomoon.svg#icomoon") format("svg");
  font-weight: normal;
  font-style: normal;
}

/* line 15, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
[class^="icon-"], [class*=" icon-"] {
  font-family: 'icomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

/* line 30, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
.button[class^="icon-"], .button[class*=" icon-"] {
  font-family: inherit;
}

/* line 33, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
.button[class^="icon-"]:before, .button[class*=" icon-"]:before {
  font-family: 'icomoon';
  margin-right: rem-calc(5px);
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

/* line 50, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
.icon-2x {
  font-size: 2em;
}

/* line 53, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
.icon-3x {
  font-size: 3em;
}

/* line 56, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont.scss */
.icon-4x {
  font-size: 4em;
}

/* line 1, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont_icons.scss */
.icon-uni2192:before {
  content: "\2192";
}

/* line 4, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont_icons.scss */
.icon-uni2190:before {
  content: "\2190";
}

/* line 7, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont_icons.scss */
.icon-uni2022:before {
  content: "\2022";
}

/* line 10, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/dummy_project/components/_webfont_icons.scss */
.icon-uni6142:before {
  content: "\6142";
}

/*
 * Libary sample #1
 */
/*
 * Libary sample #1: settings
 */
/*
 * 
 * Library #1 : sections component
 * 
 */
/* line 9, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/library_1/components/_sections.scss */
.section {
  padding: 40px 0;
}

/* line 12, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/library_1/components/_sections.scss */
.section .inner {
  padding: 10px 0;
}

/*
 * 
 * Library #1 : panels component
 * 
 */
/* line 8, /home/emencia/projects/sass_addons/boussole/tests/data_fixtures/library_1/components/_panels.scss */
.panel {
  padding: 20px;
  color: #333333;
  background-color: #f0f0f0;
  border: 1px solid #333333;
}
